==> nextcloud-20.0.8p0.tgz: nextcloud/apps/oauth2/l10n/de_DE.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Ihr Client ist nicht berechtigt, eine Verbindung herzustellen. Bitte informieren Sie den Administrator Ihres Clients.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Die Weiterleitungs-URL muss eine vollständige URL sein. Beispiel: https://ihredomain.com/pfad",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Ermöglicht OAuth2 komplatible Authentifizierung durch andere Web-Anwendungen.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Die OAuth2-App ermöglicht es Administratoren den eingebauten Authenztifizierungsablauf dahingehend zu konfigurieren, das auch ein OAuth2 komplatible Authentifizierung von anderen Web-Anwendungen aus möglich ist. ",
    "OAuth 2.0 clients" : "OAuth 2.0-Clients",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 ermöglicht es externen Diensten, Zugriff auf {instanceName} anzufordern.",
    "Add client" : "Client hinzufügen",
    "Name" : "Name",
    "Redirection URI" : "Weiterleitungs-URI",
    "Add" : "Hinzufügen",
    "Client Identifier" : "Client-Identifikationsmerkmal",
    "Secret" : "Geheimnis",
    "Show client secret" : "Geheime Zeichenkette des Clients anzeigen",
    "Delete" : "Löschen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/oauth2/l10n/de_DE.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Ihr Client ist nicht berechtigt, eine Verbindung herzustellen. Bitte informieren Sie den Administrator Ihres Clients.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Die Weiterleitungs-URL muss eine vollständige URL sein. Beispiel: https://ihredomain.com/pfad",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Ermöglicht OAuth2-kompatible Authentifizierung durch andere Web-Anwendungen.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Die OAuth2-App ermöglicht es Administratoren, den eingebauten Authentifizierungsablauf dahingehend zu konfigurieren, dass auch eine OAuth2-kompatible Authentifizierung durch andere Web-Anwendungen möglich ist. ",
    "OAuth 2.0 clients" : "OAuth 2.0-Clients",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 ermöglicht es externen Diensten, Zugriff auf {instanceName} anzufordern.",
    "Add client" : "Client hinzufügen",
    "Name" : "Name",
    "Redirection URI" : "Weiterleitungs-URI",
    "Add" : "Hinzufügen",
    "Client Identifier" : "Client-Identifikationsmerkmal",
    "Secret" : "Geheimnis",
    "Show client secret" : "Geheime Zeichenkette des Clients anzeigen",
    "Delete" : "Löschen"
},
"nplurals=2; plural=(n != 1);");
